import { z } from 'zod';

// 客户端注册验证模式
export const registerClientSchema = z.object({
    clientName: z.string().min(1, '客户端名称不能为空'),
    clientUri: z.string().url('必须是有效的URL').optional(),
    logoUri: z.string().url('必须是有效的URL').optional(),
    redirectUris: z.array(z.string().url('必须是有效的URL')).min(1, '至少需要一个重定向URI'),
    postLogoutRedirectUris: z.array(z.string().url('必须是有效的URL')).optional().default([]),
    contacts: z.array(z.string().email('必须是有效的电子邮件')).optional().default([]),
    tokenEndpointAuthMethod: z
        .enum(['client_secret_basic', 'client_secret_post', 'client_secret_jwt', 'private_key_jwt', 'none'])
        .default('client_secret_basic'),
    grantTypes: z
        .array(z.enum(['authorization_code', 'refresh_token', 'client_credentials']))
        .default(['authorization_code', 'refresh_token']),
    responseTypes: z.array(z.enum(['code', 'token', 'id_token'])).default(['code']),
    scope: z.string().default('openid profile email'),
    jwksUri: z.string().url('必须是有效的URL').optional(),
    jwks: z.string().optional(),
    policyUri: z.string().url('必须是有效的URL').optional(),
    tosUri: z.string().url('必须是有效的URL').optional(),
});

// 客户端响应模式
export const clientResponseSchema = z.object({
    id: z.string(),
    clientId: z.string(),
    clientSecret: z.string().optional(),
    clientName: z.string(),
    clientUri: z.string().optional(),
    logoUri: z.string().optional(),
    redirectUris: z.array(z.string()),
    postLogoutRedirectUris: z.array(z.string()),
    tokenEndpointAuthMethod: z.string(),
    grantTypes: z.array(z.string()),
    responseTypes: z.array(z.string()),
    scope: z.string(),
    createdTime: z.date(),
    requirePkce: z.boolean().optional(),
});

// 类型定义
export type RegisterClientInput = z.infer<typeof registerClientSchema>;
export type ClientResponse = z.infer<typeof clientResponseSchema>; 